@@ -26,13 +26,7 @@
 #include <QToolTip>
 
 #if HAVE_X11
-
-#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
-#include <private/qtx11extras_p.h>
-#else
 #include <QX11Info>
-#endif
-
 #include <netwm.h>
 #endif
 
